BFGraph: KmerHashIterator< HF > Class Template Reference

BFGraph

Public Member Functions | Data Fields
KmerHashIterator< HF > Class Template Reference

## Public Member Functions
| KmerHashIterator (const char *_s, const int _length, const int _k)
| KmerHashIterator (const KmerHashIterator &o)
bool | operator== (const KmerHashIterator &o)
bool | operator!= (const KmerHashIterator &o)
KmerHashIterator & | operator++ ()
KmerHashIterator | operator++ (int)
KmerHashIterator & | operator+= (const int length)
std::pair< uint64_t, int > & | operator* ()
std::pair< uint64_t, int > * | operator-> ()

## Data Fields
const char * | s
int | n
int | k
HF | hf
std::pair< uint64_t, int > | p_
bool | invalid

The documentation for this class was generated from the following file:

- src/KmerIterator.hpp